<h1 align="center">
  phidata
</h1>
<p align="center">
    <em>Build applications using open-source tools</em>
</p>

<p align="center">
<a href="https://python.org/pypi/phidata" target="_blank">
    <img src="https://img.shields.io/pypi/v/phidata?color=blue&label=version" alt="version">
</a>
<a href="https://github.com/phidatahq/phidata" target="_blank">
    <img src="https://img.shields.io/badge/python->=3.7-blue" alt="pythonversion">
</a>
<a href="https://github.com/phidatahq/phidata" target="_blank">
    <img src="https://pepy.tech/badge/phidata" alt="downloads">
</a>
<a href="https://github.com/phidatahq/phidata/actions/workflows/build.yml" target="_blank">
    <img src="https://github.com/phidatahq/phidata/actions/workflows/build.yml/badge.svg" alt="build-status">
</a>

[//]: # (<a href="https://github.com/phidatahq/phidata/actions/workflows/test.yml" target="_blank">)

[//]: # (    <img src="https://github.com/phidatahq/phidata/actions/workflows/test.yml/badge.svg" alt="test-status">)

[//]: # (</a>)

</p>

---


Phidata is a framework for building applications using open source tools.

## 🤔 What does that mean?

Open source tools can be used to build powerful software, but can be difficult to run and require a lot of configuration.
Phidata is a library that converts tools like FastApi, Jupyter, Redis into python classes that can be put together to build applications.

If your goal is to use open source tools for building applications, Phidata is for you.
It also provides a library of pre-configured tech stacks which makes it easy to get started with common use cases.

## 🚀 How it works

- Phidata provides pre-configured tech stacks for different use cases.
- **Create your codebase** from a template using `phi ws create`
- **Run your app locally** using `phi ws up dev:docker`
- **Run your app on AWS** using `phi ws up prd:aws`
- **Integrate** with your front-end or product using APIs.

## More Information:

- **Documentation**: <a href="https://docs.phidata.com" target="_blank">https://docs.phidata.com</a>
- **Questions:** Chat with us on <a href="https://discord.gg/4MtYHHrgA8" target="_blank">Discord</a>
- **Email**: <a href="mailto:help@phidata.com" target="_blank">help@phidata.com</a>
